package com.hrsk.cloud.eg.infrastructure.business;

import com.alibaba.fastjson2.JSONObject;
import com.google.common.collect.Lists;
import com.hrsk.cloud.eg.constant.BusinessPrefixEnum;
import com.hrsk.cloud.eg.domain.api.FunctionObject;
import com.hrsk.cloud.eg.domain.api.HttpApiConfig;
import com.hrsk.cloud.eg.domain.api.KeyValueObject;
import com.hrsk.cloud.eg.domain.api.ValueObject;
import com.hrsk.cloud.eg.domain.api.common.ApiPayloadTypeEnum;
import com.hrsk.cloud.eg.domain.api.common.ValueObjectTypeEnum;
import com.hrsk.cloud.eg.domain.common.utils.GsonUtils;
import com.hrsk.cloud.eg.domain.common.utils.SnowflakeIdWorker;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgApiDo;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgApiEndpointDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiEndpointService;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author zhangyy
 * @version 1.0
 * @description: GenerateHttpApiConfig 迁移api配置的处理类
 * @date 2024/8/29 17:54
 */
@Slf4j
@Service
public class GenerateHttpApiConfigService {

    @Resource
    private EgApiService egApiService;

    @Resource
    private EgApiEndpointService egApiEndpointService;

    /**
     * @description:  原始惠融对接api转化
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/8/29 17:58
     */
    public void  generateHuiRonHuiRonApiConfig(String huiRonApiConfig){
        EgApiDo egApiDo=new EgApiDo();
        egApiDo.setApiCode("EG:"+BusinessPrefixEnum.CHECK_INTO_PREFIX.getCode()+":HUIRONG_CRM:9");
        egApiDo.setApiName(BusinessPrefixEnum.CHECK_INTO_PREFIX.getMsg());
        egApiService.save(egApiDo);
        EgApiEndpointDo egApiEndpointDo=new EgApiEndpointDo();
        egApiEndpointDo.setApiCode(egApiDo.getApiCode());
        egApiEndpointDo.setApiId(egApiDo.getId());
        egApiEndpointDo.setApiConfig(HessianUtils.serialize(createCheckIntoBean(huiRonApiConfig)));
        egApiEndpointService.save(egApiEndpointDo);
    }

    /**
     * @description: 创建撞库httpApi信息
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/8/30 09:31
     */
    public HttpApiConfig createCheckIntoBean(String param){
        JSONObject jsonObject=JSONObject.parseObject(param);
        HttpApiConfig httpApiConfig = new HttpApiConfig();
        httpApiConfig.setUrl(jsonObject.getString("checkUrl"));
        httpApiConfig.setMethod("POST");
        httpApiConfig.setContentType(ApiPayloadTypeEnum.APPLICATION_JSON.getCode());
        List<KeyValueObject> headers = Lists.newArrayList();
        KeyValueObject head=new KeyValueObject();
        head.setType(ValueObjectTypeEnum.BASIC.getType());
        head.setKey("Content-Type");
        head.setValue("application/json");
        headers.add(head);
        httpApiConfig.setHeader(headers);
        JSONObject body=new  JSONObject();
        KeyValueObject attackPhone=new KeyValueObject();
        attackPhone.setType("spel");
        attackPhone.setValue("#param.user.phoneMd5");
        KeyValueObject merchantNo=new KeyValueObject();
        merchantNo.setType("spel");
        merchantNo.setValue("#param.plan.bid");
        body.put("attackPhone","#"+JSONObject.toJSONString(attackPhone));
        body.put("merchantNo","#"+JSONObject.toJSONString(merchantNo));
        //主体
        httpApiConfig.setContent(JSONObject.toJSONString(body));
        JSONObject resultObj=new  JSONObject();
        KeyValueObject status=new KeyValueObject();
        status.setType("spel");
        status.setValue("#root[data][status]");
        resultObj.put("status","#"+JSONObject.toJSONString(status));
        httpApiConfig.setResult(JSONObject.toJSONString(resultObj));
        String jsonString = JSONObject.toJSONString(httpApiConfig);
        log.info("json input data {}",jsonString);
         return httpApiConfig;
    }

}